Changelog
=========

Version 0.2 [2015-01-14]
------------------------

- `#1 <https://github.com/openwisp/django-netjsonconfig/issues/1>`_:
  upgraded to django-netjsonconfig 0.2

Version 0.1 [2015-12-21]
------------------------

- ``get_config`` view
- ``get_config_md5`` view
- ``OWM_LEGACY_ALLOWED_SUBNETS`` setting
